@@ -11,7 +11,7 @@ from ground_soil.filesystem import temporary_directory, rsync
 from beanstalk import (IDENTIFIER as beanstalk_identifier, BEANSTALK_LOCAL_BASE_PATH,
                        __version__ as beanstalk_version_string, VERSION as beanstalk_version_tuple)
 from beanstalk.tasks.utils import set_verbose_level, load_role_settings, load_web_servers, run_hooked_actions
-from beanstalk.decorators import beanstalk_role
+from beanstalk.decorators import beanstalk_task
 from beanstalk.console.titles import section_title, tool_title, separator
 from beanstalk.validator import validate_web_server, validate_file_existence, validate_project_type, supported_projects
 
@@ -41,8 +41,7 @@ def web_server(*servers):
         })
 
 
-@task
-@beanstalk_role('app')
+@beanstalk_task(beanstalk_role='app')
 def plant(VERBOSE=0):
     """plant beanstalk-stack for project in current work directory
     """
@@ -133,8 +132,7 @@ def plant(VERBOSE=0):
     print green('Planted. Grow up now!')
 
 
-@task
-@beanstalk_role('app')
+@beanstalk_task(beanstalk_role='app')
 def deploy(settings_path=None, **settings_patches):
     """Deploy project in current work folder to beanstalk-stack
     """
@@ -232,8 +230,7 @@ def deploy(settings_path=None, **settings_patches):
             print green('Deployed!')
 
 
-@roles('web_servers')
-@beanstalk_role('app')
+@beanstalk_task(beanstalk_role='app')
 def deploy_remote_core():
     """ The part to run on each server
     """
@@ -315,8 +312,7 @@ def deploy_remote_core():
     print separator(' . ')
 
 
-@task
-@beanstalk_role('app')
+@beanstalk_task(beanstalk_role='app')
 def activate(settings_path=None, **settings_patches):
     """Activate apps in the remote
     """
@@ -332,8 +328,7 @@ def activate(settings_path=None, **settings_patches):
     execute(core)
 
 
-@task
-@beanstalk_role('app')
+@beanstalk_task(beanstalk_role='app')
 def deactivate(settings_path=None, **settings_patches):
     """Deactivate apps in the remote
     """
